:root {
    --text: black;
    --title: black;
    --primary: black;
    --background: white;
    --color-black: #000000;
    --color-white: #ffffff;
    --color-blue: #4051b5;
    --color-green: #4cae4f;
    --color-yellow: #f1dc15;
    --color-orange: #ffa724;
    --color-purple: #ab47bd;
    --color-red: #ff2c06;
}

body {
    color: var(--text);
    background-color: var(--background);
}

small {
    color: var(--text);
}

code {
    background-color: var(--primary);
    color: var(--background) !important;
}

pre {
    background-color: var(--primary);
}

a {
    color: var(--text) !important;
    text-decoration: underline;
}

a:focus,a:hover {
    color: var(--primary) !important;
    text-decoration: underline;
}

p {
    color: var(--text);
}

p a {
    font-weight: 400;
    color: var(--primary);
    text-decoration: underline;
    text-underline-position: under;
}

p a:focus,p a:hover {
    color: var(--primary);
}

h1,h2,h3,h4,h5,h6 {
    color: var(--title);
    letter-spacing: .0625em;
    margin: 3.2rem 0 1.6rem 0;
}

blockquote {
    border-left: 2px solid #dcdcdc;
}

table td,table th {
    border: 2px solid var(--primary);
}

.title-color {
    color: var(--title);
}

.dropdown-menu {
    color: var(--background);
    background-color: var(--background);
    border-color: var(--primary);
}

.dropdown-item.active, .dropdown-item:active, .dropdown-item:hover {
    color: var(--background) !important;
    background-color: var(--primary) !important;
}


@media only screen and (max-width: 1200px) {
    .source-detail {
        border-color: var(--primary);
    }
}
